@@ -681,11 +681,11 @@ dynterms2formula <- function(x, response.name = NULL){
     # if there are still some lags, write them
     if (length(theinst) > 0L){
       if (length(theinst) > 1L){
-        at <- c(at, paste("lag(", names(x)[i], ",c(",
-                          paste(theinst, collapse = ","), "))", sep =""))
+        at <- c(at, paste0("lag(", names(x)[i], ",c(",
+                          paste(theinst, collapse = ","), "))"))
       }
       else{
-        at <- c(at, paste("lag(", names(x)[i], ",", theinst, ")", sep =""))
+        at <- c(at, paste0("lag(", names(x)[i], ",", theinst, ")"))
       }
     }
     result <- c(result, at)
@@ -699,7 +699,7 @@ extract.data <- function(data, form, as.matrix = TRUE){
   trms <- terms(form)
   has.response  <- attr(trms, 'response')  == 1
   has.intercept <- attr(trms, 'intercept') == 1
-  if (has.intercept == 1){
+  if(has.intercept){
     # Formula is unable to update formulas with no lhs
     form <- Formula(update(formula(form), ~ . -1))
 #    form <- update(form, ~. -1)
@@ -767,7 +767,7 @@ makegmm <- function(x, g, TL1, collapse = FALSE){
     result <- m
    }
    else {
-     lx <- vapply(x, length, FUN.VALUE = 0.0)
+     lx <- lengths(x)
      n <- length(x)
      lxc <- cumsum(lx)
      before <- c(0, lxc[-n])
@@ -1010,7 +1010,8 @@ print.summary.pgmm <- function(x, digits = max(3, getOption("digits") - 2),
 #' 
 #' @param object an object of class `"pgmm"`,
 #' @param weights the weighting matrix to be used for the computation of the
-#' test.
+#' test,
+#' @param \dots further arguments (currently unused).
 #' @return An object of class `"htest"`.
 #' @export
 #' @author Yves Croissant
@@ -1030,7 +1031,13 @@ print.summary.pgmm <- function(x, digits = max(3, getOption("digits") - 2),
 #'            data = EmplUK, effect = "twoways", model = "twosteps")
 #' sargan(ar)
 #' 
-sargan <- function(object, weights = c("twosteps", "onestep")) {
+sargan <- function(object, ...) {
+  UseMethod("sargan")
+}
+
+#' @rdname sargan
+#' @export
+sargan.pgmm <- function(object, weights = c("twosteps", "onestep"), ...) {
   if (!inherits(object, "pgmm")) stop("argument 'object' needs to be class 'pgmm'")
   weights <- match.arg(weights)
   model <- describe(object, "model")
