@@ -216,7 +216,7 @@ pmg <- function(formula, data, subset, na.action,
       }
 
       ## add names of coefs for augmented x-sectional averages
-      coef.names.bar <- c("y.bar", paste(coef.names[-1L], ".bar", sep=""))
+      coef.names.bar <- c("y.bar", paste0(coef.names[-1L], ".bar"))
       coef.names <- c(coef.names, coef.names.bar)
       ## 'trend' always comes last
       if(trend) coef.names <- c(coef.names, "trend")
@@ -319,7 +319,7 @@ print.summary.pmg <- function(x, digits = max(3, getOption("digits") - 2),
                               width = getOption("width"), ...){
   pmodel <- attr(x, "pmodel")
   pdim   <- attr(x, "pdim")
-  cat(paste(model.pmg.list[pmodel$model.name], "\n", sep=""))
+  cat(paste0(model.pmg.list[pmodel$model.name], "\n"))
   cat("\nCall:\n")
   print(x$call)
   cat("\n")
@@ -328,9 +328,9 @@ print.summary.pmg <- function(x, digits = max(3, getOption("digits") - 2),
   print(sumres(x))
   cat("\nCoefficients:\n")
   printCoefmat(x$CoefTable, digits = digits)
-  cat(paste("Total Sum of Squares: ",    signif(x$tss,  digits), "\n", sep=""))
-  cat(paste("Residual Sum of Squares: ", signif(x$ssr,  digits), "\n", sep=""))
-  cat(paste("Multiple R-squared: ",      signif(x$rsqr, digits), "\n", sep=""))
+  cat(paste0("Total Sum of Squares: ",    signif(x$tss,  digits), "\n"))
+  cat(paste0("Residual Sum of Squares: ", signif(x$ssr,  digits), "\n"))
+  cat(paste0("Multiple R-squared: ",      signif(x$rsqr, digits), "\n"))
   invisible(x)
 }
 
