@@ -356,13 +356,12 @@ print.summary.plm <- function(x, digits = max(3, getOption("digits") - 2),
   has.instruments <- (length(formula)[2L] >= 2L)
   effect <- describe(x, "effect")
   model  <- describe(x, "model")
-  if (model != "pooling") { cat(paste(effect.plm.list[effect], " ", sep = "")) }
-  cat(paste(model.plm.list[model], " Model", sep = ""))
+  if (model != "pooling") { cat(paste0(effect.plm.list[effect], " ")) }
+  cat(paste0(model.plm.list[model], " Model"))
   
   if (model == "random"){
     ercomp <- describe(x, "random.method")
-    cat(paste(" \n   (", random.method.list[ercomp], "'s transformation)\n",
-              sep = ""))
+    cat(paste0(" \n   (", random.method.list[ercomp], "'s transformation)\n"))
   }
   else{
     cat("\n")
@@ -419,24 +418,24 @@ print.summary.plm <- function(x, digits = max(3, getOption("digits") - 2),
   if (is.null(subset)) printCoefmat(coef(x), digits = digits)
   else printCoefmat(coef(x)[subset, , drop = FALSE], digits = digits)
   cat("\n")
-  cat(paste("Total Sum of Squares:    ", signif(tss(x),      digits), "\n", sep = ""))
-  cat(paste("Residual Sum of Squares: ", signif(deviance(x), digits), "\n", sep = ""))
-  cat(paste("R-Squared:      ", signif(x$r.squared[1L], digits),      "\n", sep = ""))
-  cat(paste("Adj. R-Squared: ", signif(x$r.squared[2L], digits),      "\n", sep = ""))
+  cat(paste0("Total Sum of Squares:    ", signif(tss(x),      digits), "\n"))
+  cat(paste0("Residual Sum of Squares: ", signif(deviance(x), digits), "\n"))
+  cat(paste0("R-Squared:      ", signif(x$r.squared[1L], digits),      "\n"))
+  cat(paste0("Adj. R-Squared: ", signif(x$r.squared[2L], digits),      "\n"))
 
   # print Wald test of joint sign. of regressors only if there is a statistic
   # in summary.plm object (not computed by summary.plm if there are no other
   # regressors than the intercept
   if(!is.null(fstat <- x$fstatistic)) {
     if (names(fstat$statistic) == "F"){
-      cat(paste("F-statistic: ", signif(fstat$statistic),
+      cat(paste0("F-statistic: ", signif(fstat$statistic),
                 " on ", fstat$parameter["df1"]," and ", fstat$parameter["df2"],
-                " DF, p-value: ", format.pval(fstat$p.value,digits=digits), "\n", sep=""))
+                " DF, p-value: ", format.pval(fstat$p.value,digits=digits), "\n"))
     }
     else{
-      cat(paste("Chisq: ", signif(fstat$statistic),
+      cat(paste0("Chisq: ", signif(fstat$statistic),
                 " on ", fstat$parameter,
-                " DF, p-value: ", format.pval(fstat$p.value, digits = digits), "\n", sep=""))
+                " DF, p-value: ", format.pval(fstat$p.value, digits = digits), "\n"))
     }
   }
   invisible(x)
@@ -484,7 +483,7 @@ print.summary.plm <- function(x, digits = max(3, getOption("digits") - 2),
 #' @return A numeric (or a pseries if `newdata` is a pdata.frame) carrying the 
 #'         predicted values with length equal to the number of rows as the data 
 #'         supplied in `newdata` and with names the row names of `newdata` or, if 
-#'         `newdata = NULL`, the fitted values the original model given in `object`.
+#'         `newdata = NULL`, the original model's fitted values given in `object`.
 #' @keywords regression
 #' @export
 #' @rdname predict.plm
@@ -525,26 +524,36 @@ predict.plm <- function(object, newdata = NULL, na.fill = !inherits(newdata, "pd
   #     newdata = NULL (output is compressed data) and for 
   #     newdata = original pdata.frame (output has original length)
   
-  tt <- terms(object)
   if(is.null(newdata)){ 
-    # return fitted values of estimated model and exit
+    # result is simply fitted values of estimated model
     result <- fitted_exp.plm(object, ...) # fitted_exp.plm gives outer model's fitted values
   }
   else{
-    Terms <- delete.response(tt)
-    m <- model.frame(Terms, newdata)
-    X <- model.matrix(Terms, m)
+    
+    # begin case newdata != NULL
+    is.pdf <- inherits(newdata, "pdata.frame")
+    
+    # model frame and model matrix without response (as not needed)
+    if(is.pdf) {
+      m <- model.frame(newdata, object$formula, lhs = 0)
+      X <- model.matrix(m)
+    } else {
+      tt <- terms(object)
+      Terms <- delete.response(tt)
+      m <- model.frame(Terms, newdata)
+      X <- model.matrix(Terms, m)
+    }
+    
     beta <- coef(object)
     model <- describe(object, "model")
-    is.pdf <- inherits(newdata, "pdata.frame")
     
     if(model == "within") {
       # remove intercept if contained in the formula/terms and, thus, in the 
       # model matrix
       #  (usually, users does not explicitly suppress the
       #  intercept in FE models (e.g., by response ~ 0 + depvars), but we need 
-      #  to cater for that suppressed-case as well by has.intercept(tt))
-      if(has.intercept(tt)) X <- X[ , -1L, drop = FALSE]
+      #  to cater for that suppressed-case as well by has.intercept(object))
+      if(has.intercept(object)) X <- X[ , -1L, drop = FALSE]
       effect <- describe(object, "effect")
       effs.orig <- fixef(object, effect = effect)
       
@@ -562,7 +571,7 @@ predict.plm <- function(object, newdata = NULL, na.fill = !inherits(newdata, "pd
 
           effs <- effs.orig[levels(newdata.idx.eff)][newdata.idx.eff] # has length corresponding to newdata
           
-          if(na.fill & sum(out.of.sample <- !newdata.idx.eff %in% model.idx.eff) > 0L) {
+          if(na.fill && sum(out.of.sample <- !newdata.idx.eff %in% model.idx.eff) > 0L) {
             pdim <- pdim(object)
             effs[out.of.sample] <- weighted.mean(effs.orig, w = pdim$Tint[[idx]])
           }
@@ -583,7 +592,7 @@ predict.plm <- function(object, newdata = NULL, na.fill = !inherits(newdata, "pd
           
           effs <- effs.orig[newdata.idx.tw] # has length corresponding to newdata
           
-          if(na.fill & sum(out.of.sample <- !newdata.idx.tw %in% model.idx.tw) > 0L) {
+          if(na.fill && sum(out.of.sample <- !newdata.idx.tw %in% model.idx.tw) > 0L) {
             pdim <- pdim(object)
             effs[out.of.sample] <- mean(effs.orig)
           }
@@ -600,15 +609,18 @@ predict.plm <- function(object, newdata = NULL, na.fill = !inherits(newdata, "pd
         effs <- rep(effs, nrow(X))
       }
     } # end-if model == "within"
+    
     result <- as.numeric(tcrossprod(beta, X)) + if(model == "within") effs else 0
     # if newdata is a pdata.frame output a pseries w/ index stripped down to what
     # is left after NA-omitting (performed implicitly by model.frame)
+    rmrows <- unclass(attr(m, "na.action"))
+    nms <- rownames(newdata)
     if(is.pdf) {
-      result.index <- if(!is.null(rmrows <- unclass(attr(m, "na.action")))) index(newdata[-rmrows, ]) else index(newdata)
+      result.index <- if(!is.null(rmrows)) index(newdata[-rmrows, ]) else index(newdata)
       result <- add_pseries_features(result, result.index)
     }
-    names(result) <- rownames(m)
-  }
+    names(result) <- if(!is.null(rmrows)) nms[-rmrows] else nms
+  } # end case newdata != NULL
   result
 }
 
