@@ -54,8 +54,6 @@
 #' pGrunfeld <- pdata.frame(Grunfeld)
 #' 
 #' # then make a model frame from a formula and a pdata.frame
-##pform <- pFormula(inv ~ value + capital)
-##mf <- model.frame(pform, data = pGrunfeld)
 #' form <- inv ~ value
 #' mf <- model.frame(pGrunfeld, form)
 #' 
@@ -82,7 +80,7 @@ model.frame.pdata.frame <- function(formula, data = NULL, ...,
                                     lhs = NULL, rhs = NULL, dot = "previous"){
     pdata <- formula
     formula <- as.Formula(data)
-    if (is.null(rhs)) rhs <- 1:(length(formula)[2L])
+    if (is.null(rhs)) rhs <- seq_len(length(formula)[2L])
     if (is.null(lhs)) lhs <- if(length(formula)[1L] > 0L) 1 else 0
     index <- attr(pdata, "index")
     mf <- model.frame(formula, as.data.frame(pdata, row.names = FALSE), ..., # NB need row.names = FALSE to ensure mf has integer sequence as row names
@@ -145,7 +143,7 @@ model.matrix.pdata.frame <- function(object,
     effect <- match.arg(effect)
     formula <- attr(object, "formula")
     data <- object
-    has.intercept <- has.intercept(formula, rhs = rhs)
+    has.intercept <- has.intercept(formula, rhs = rhs, data = data)
     # relevant defaults for cstcovar.rm
     if(is.null(cstcovar.rm)) cstcovar.rm <- if(model == "within") "intercept" else "none"
     balanced <- is.pbalanced(data)
@@ -166,8 +164,8 @@ model.matrix.pdata.frame <- function(object,
     if(model == "Between") X <- Between(X, effect)
     if(model == "between") X <- between(X, effect)
     if(model == "mean")    X <- Mean(X)
-    if(model == "fd")      X <- pdiff(X, effect = "individual",
-                                   has.intercept = has.intercept)
+    if(model == "fd")      X <- pdiff(X, effect = "individual",   # pdiff has its own handling of intercept and const. columns
+                                   has.intercept = has.intercept, shift = "row")
     if(model == "random"){
         if(is.null(theta)) stop("a theta argument must be provided for model = \"random\"")
         if(effect %in% c("time", "individual")) X <- X - theta * Between(X, effect)
@@ -211,7 +209,8 @@ model.matrix.pdata.frame <- function(object,
 #' 
 #' The model response is extracted from a `pdata.frame` (where the
 #' response must reside in the first column; this is the case for a
-#' model frame), a `pFormula` + `data` or a `plm` object, and the
+#' model frame), a `Formula` + `data` (being a model frame) or a `plm` 
+#' object, and the
 #' transformation specified by `effect` and `model` is applied to
 #' it.\cr Constructing the model frame first ensures proper `NA`
 #' handling and the response being placed in the first column, see
@@ -239,13 +238,10 @@ model.matrix.pdata.frame <- function(object,
 #' data("Grunfeld", package = "plm")
 #' pGrunfeld <- pdata.frame(Grunfeld)
 #' 
-#' # then make a model frame from a pFormula and a pdata.frame
-#' 
-#' 
+#' # then make a model frame from a Formula and a pdata.frame
 #' form <- inv ~ value + capital
 #' mf <- model.frame(pGrunfeld, form)
-#' # construct (transformed) response of the within model
-#' resp <- pmodel.response(form, data = mf, model = "within", effect = "individual")
+#'
 #' # retrieve (transformed) response directly from model frame
 #' resp_mf <- pmodel.response(mf, model = "within", effect = "individual")
 #' 
@@ -254,7 +250,7 @@ model.matrix.pdata.frame <- function(object,
 #' pmodel.response(fe_model)
 #' 
 #' # same as constructed before
-#' all.equal(resp, pmodel.response(fe_model), check.attributes = FALSE) # TRUE
+#' all.equal(resp_mf, pmodel.response(fe_model), check.attributes = FALSE) # TRUE
 #' 
 pmodel.response <- function(object, ...) {
     UseMethod("pmodel.response")
@@ -282,28 +278,32 @@ pmodel.response.data.frame <- function(object, ...){
     model  <- if(is.null(dots$model))  "pooling"    else dots$model
     effect <- if(is.null(dots$effect)) "individual" else dots$effect
     theta  <- if(is.null(dots$theta))  NULL         else dots$theta
-    y <- model.response(object)
+    y <- model.response(object) # has index attribute but not class 'pseries'
+    class(y) <- unique(c("pseries", class(y)))
     ptransform(y, model = model, effect = effect, theta = theta)
 }
 
-# deprecated
+# "deprecated" (not advertised anymore)
 #' @rdname pmodel.response
 #' @export
 pmodel.response.formula <- function(object, data, ...){
-    dots <- list(...)
-    if(is.null(data)) stop("the data argument is mandatory")
-    if(! inherits(data, "pdata.frame")) stop("the data argument must be a pdata.frame")
-    if(is.null(attr(data, "terms"))) data <- model.frame(data, object)
-    model  <- dots$model
-    effect <- dots$effect
-    theta  <- dots$theta
-    if(is.null(model)) model <- "pooling"
-    if(is.null(effect)) effect <- "individual"
-    if(model == "random" && is.null(theta)) stop("the theta argument is mandatory for model = \"random\"")
-    y <- model.response(data)
-    ptransform(y, model = model, effect = effect, theta = theta)
+  #  print("pmodel.response.formula")
+  dots <- list(...)
+  if(is.null(data)) stop("the data argument is mandatory")
+  if(! inherits(data, "pdata.frame")) stop("the data argument must be a pdata.frame")
+  if(is.null(attr(data, "terms"))) data <- model.frame(data, object)
+  model  <- dots$model
+  effect <- dots$effect
+  theta  <- dots$theta
+  if(is.null(model)) model <- "pooling"
+  if(is.null(effect)) effect <- "individual"
+  if(model == "random" && is.null(theta)) stop("the theta argument is mandatory for model = \"random\"")
+  y <- model.response(data)
+  class(y) <- unique(c("pseries", class(y)))
+  ptransform(y, model = model, effect = effect, theta = theta)
 }
 
+
 ptransform <- function(x, model = NULL, effect = NULL, theta = NULL, ...){
     # NB: ptransform (and hence pmodel.response) does not handle the random 2-way unbalanced case
     
@@ -314,7 +314,7 @@ ptransform <- function(x, model = NULL, effect = NULL, theta = NULL, ...){
     if(model == "within")  x <- Within(x, effect)
     if(model == "between") x <- between(x, effect)
     if(model == "Between") x <- Between(x, effect)
-    if(model == "fd")      x <- pdiff(x, "individual")
+    if(model == "fd")      x <- pdiff(x, effect = "individual", shift = "row")
     if(model == "random") {
         balanced <- is.pbalanced(x) # need to check this right here as long as x is a pseries
         if(is.null(theta)) stop("a theta argument must be provided")
