@@ -8,136 +8,158 @@
 ##    mechanism: options("plm.fast" = TRUE).
 
 ## ad 1) new name for base R functions defined in tool_transformations.R
-Sum.default.baseR <- plm:::Sum.default
-Sum.pseries.baseR <- plm:::Sum.pseries
-Sum.matrix.baseR  <- plm:::Sum.matrix
+Sum_default_baseR <- plm:::Sum.default
+Sum_pseries_baseR <- plm:::Sum.pseries
+Sum_matrix_baseR  <- plm:::Sum.matrix
 
-between.default.baseR <- plm:::between.default
-between.pseries.baseR <- plm:::between.pseries
-between.matrix.baseR  <- plm:::between.matrix
+between_default_baseR <- plm:::between.default
+between_pseries_baseR <- plm:::between.pseries
+between_matrix_baseR  <- plm:::between.matrix
 
-Between.default.baseR <- plm:::Between.default
-Between.pseries.baseR <- plm:::Between.pseries
-Between.matrix.baseR  <- plm:::Between.matrix
+Between_default_baseR <- plm:::Between.default
+Between_pseries_baseR <- plm:::Between.pseries
+Between_matrix_baseR  <- plm:::Between.matrix
 
-Within.default.baseR <- plm:::Within.default
-Within.pseries.baseR <- plm:::Within.pseries
-Within.matrix.baseR  <- plm:::Within.matrix
+Within_default_baseR  <- plm:::Within.default
+Within_pseries_baseR <- plm:::Within.pseries
+Within_matrix_baseR   <- plm:::Within.matrix
 
-pseriesfy.baseR      <- plm:::pseriesfy # ... in tool_pdata.frame.R:
+pdiff_baseR           <- plm:::pdiff
 
+pseriesfy_baseR       <- plm:::pseriesfy # ... in tool_pdata.frame.R:
+
+## lag, lead, diff: are collapse-powered but in file tool_transformations.R (incl. their wrappers).
 
 ## ad 2) implement wrapper switches
 
 #### Sum wrapper switches ####
 Sum.default <- function(x, effect, ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    Sum.default.baseR(x, effect, ...) } else {
+    Sum_default_baseR(x, effect, ...) } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-    Sum.default.collapse(x, effect, ...) }
+    Sum_default_collapse(x, effect, ...) }
 }
 
 Sum.pseries <- function(x, effect = c("individual", "time", "group"), ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    Sum.pseries.baseR(x, effect, ...) } else {
+    Sum_pseries_baseR(x, effect, ...) } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-    Sum.pseries.collapse(x, effect, ...) }
+    Sum_pseries_collapse(x, effect, ...) }
 }
 
 Sum.matrix <- function(x, effect, ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    Sum.matrix.baseR(x, effect, ...) } else {
+    Sum_matrix_baseR(x, effect, ...) } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-    Sum.matrix.collapse(x, effect, ...) }
+    Sum_matrix_collapse(x, effect, ...) }
 }
 
 #### Between wrapper switches ####
 Between.default <- function(x, effect, ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    Between.default.baseR(x, effect, ...) } else {
+    Between_default_baseR(x, effect, ...) } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-    Between.default.collapse(x, effect, ...) }
+    Between_default_collapse(x, effect, ...) }
 }
   
 Between.pseries <- function(x, effect = c("individual", "time", "group"), ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    Between.pseries.baseR(x, effect, ...) } else {
+    Between_pseries_baseR(x, effect, ...) } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-    Between.pseries.collapse(x, effect, ...) }
+    Between_pseries_collapse(x, effect, ...) }
 }
 
 Between.matrix <- function(x, effect, ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    Between.matrix.baseR(x, effect, ...) } else {
+    Between_matrix_baseR(x, effect, ...) } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-    Between.matrix.collapse(x, effect, ...) }
+    Between_matrix_collapse(x, effect, ...) }
 }
 
 #### between wrapper switches ####
 between.default <- function(x, effect, ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-     between.default.baseR(x, effect, ...) } else {
+     between_default_baseR(x, effect, ...) } else {
      if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-     between.default.collapse(x, effect, ...) }
+     between_default_collapse(x, effect, ...) }
 }
 
 between.pseries <- function(x, effect = c("individual", "time", "group"), ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    between.pseries.baseR(x, effect, ...) } else {
+    between_pseries_baseR(x, effect, ...) } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-    between.pseries.collapse(x, effect, ...) }
+    between_pseries_collapse(x, effect, ...) }
 }
 
 between.matrix <- function(x, effect, ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    between.matrix.baseR(x, effect, ...) } else {
+    between_matrix_baseR(x, effect, ...) } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-    between.matrix.collapse(x, effect, ...) }
+    between_matrix_collapse(x, effect, ...) }
 }
 
 #### Within wrapper switches ####
 Within.default <- function(x, effect, ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    Within.default.baseR(x, effect, ...) } else {
+    Within_default_baseR (x, effect, ...) } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-    Within.default.collapse(x, effect, ...) }
+    Within_default_collapse(x, effect, ...) }
 }
 
 Within.pseries <- function(x, effect = c("individual", "time", "group", "twoways"), ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    Within.pseries.baseR(x, effect, ...)
+    Within_pseries_baseR(x, effect, ...)
   } else {
     if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
 
     if(is.null(getOption("plm.fast.pkg.FE.tw"))) options("plm.fast.pkg.FE.tw" = "collapse")
     switch(getOption("plm.fast.pkg.FE.tw"),
-           "collapse" = Within.pseries.collapse(       x, effect, ...), # collapse only,
-           "fixest"   = Within.pseries.collapse.fixest(x, effect, ...), # collapse for 1-way FE + fixest for 2-way FE,
-           "lfe"      = Within.pseries.collapse.lfe(   x, effect, ...), # collapse for 1-way FE + lfe for 2-way FE,
+           "collapse" = Within_pseries_collapse(       x, effect, ...),  # collapse only,
+           "fixest"   = Within_pseries_collapse_fixest(x, effect, ...),  # collapse for 1-way FE + fixest for 2-way FE,
+           "lfe"      = Within_pseriesc_collapse_lfe(   x, effect, ...), # collapse for 1-way FE + lfe    for 2-way FE
            stop("unknown value of option 'plm.fast.pkg.FE.tw'"))
   }
 }
 
 Within.matrix <- function(x, effect, ...) {
   if(!isTRUE(getOption("plm.fast"))) {
-    Within.matrix.baseR(x, effect, ...) 
+    Within_matrix_baseR(x, effect, ...) 
   } else {
     if (!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
     
     if(is.null(getOption("plm.fast.pkg.FE.tw"))) options("plm.fast.pkg.FE.tw" = "collapse")
     switch(getOption("plm.fast.pkg.FE.tw"),
-           "collapse" = Within.matrix.collapse(       x, effect, ...), # collapse only,
-           "fixest"   = Within.matrix.collapse.fixest(x, effect, ...), # collapse for 1-way FE + fixest for 2-way FE,
-           "lfe"      = Within.matrix.collapse.lfe(   x, effect, ...), # collapse for 1-way FE + lfe for 2-way FE,
+           "collapse" = Within_matrix_collapse(       x, effect, ...), # collapse only,
+           "fixest"   = Within_matrix_collapse_fixest(x, effect, ...), # collapse for 1-way FE + fixest for 2-way FE,
+           "lfe"      = Within_matrix_collapse_lfe(   x, effect, ...), # collapse for 1-way FE + lfe    for 2-way FE
            stop("unknown value of option 'plm.fast.pkg.FE.tw'"))
   }
 }
 
+#### wrapper for pdiff ####
+pdiff <- function(x, effect = c("individual", "time"), has.intercept = FALSE,
+                  shift = c("time", "row")) {
+  if(!isTRUE(getOption("plm.fast"))) {
+    pdiff_baseR(x, effect, has.intercept, shift) } else {
+      if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
+      pdiff.collapse(x, effect, has.intercept, shift) }
+}
+
+
+#### wrapper for pseriesfy ####
+# both pseriesfy functions are in file tool_pdata.frame.R 
+pseriesfy <- function(x,  ...) {
+  if(!isTRUE(getOption("plm.fast"))) {
+    pseriesfy_baseR(x, ...) } else {
+      if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
+      pseriesfy.collapse(x, ...) }
+}
+
 
 #### Sum ####
 
-Sum.default.collapse <- function(x, effect, ...) {
-# print("Sum.default.collapse")
+Sum_default_collapse <- function(x, effect, ...) {
+# print("Sum_default_collapse")
 # browser()
   # argument 'effect' is assumed to be a factor
 
@@ -149,9 +171,10 @@ Sum.default.collapse <- function(x, effect, ...) {
   return(res)
 }
 
-Sum.pseries.collapse <- function(x, effect = c("individual", "time", "group"), ...) {
-# print("Sum.pseries.collapse")
+Sum_pseries_collapse <- function(x, effect = c("individual", "time", "group"), ...) {
+# print("Sum_pseries_collapse")
 # browser()
+  
   effect <- match.arg(effect)
   # check for presence of na.rm in dots, if not present set to FALSE
   na.rm <- if(missing(...) || is.null(na.rm <- list(...)$na.rm)) FALSE else na.rm
@@ -169,9 +192,10 @@ Sum.pseries.collapse <- function(x, effect = c("individual", "time", "group"), .
   return(res)
 }
 
-Sum.matrix.collapse <- function(x, effect, ...) {
-# print("Sum.matrix.collapse")
+Sum_matrix_collapse <- function(x, effect, ...) {
+# print("Sum_matrix_collapse")
 # browser()
+  
   # if no index attribute, argument 'effect' is assumed to be a factor
   eff.fac <- if(is.null(xindex <- attr(x, "index"))) {
     effect
@@ -201,8 +225,8 @@ Sum.matrix.collapse <- function(x, effect, ...) {
 
 # Need separate implementations of Between.pseries and between.pseries due to different NA handling
 
-Between.default.collapse <- function(x, effect, ...) {
-# print("Between.default.collapse")
+Between_default_collapse <- function(x, effect, ...) {
+# print("Between_default_collapse")
 # browser()
   
   # argument 'effect' is assumed to be a factor
@@ -215,8 +239,8 @@ Between.default.collapse <- function(x, effect, ...) {
   return(res)
 }
 
-between.default.collapse <- function(x, effect, ...) {
-# print("between.default.collapse")
+between_default_collapse <- function(x, effect, ...) {
+# print("between_default_collapse")
 # browser()
   
   # argument 'effect' is assumed to be a factor
@@ -224,7 +248,7 @@ between.default.collapse <- function(x, effect, ...) {
   # check for presence of na.rm in dots, if not present set to FALSE
   na.rm <- if(missing(...) || is.null(na.rm <- list(...)$na.rm)) FALSE else na.rm
   res <- collapse::fbetween(x, g = effect, w = NULL, na.rm = na.rm, fill = TRUE)
-  keep <- !duplicated(effect)
+  keep <- !collapse::fduplicated(effect, all = FALSE)
   res <- res[keep]
   names(res) <- as.character(effect[keep])
   # bring into factor level order (not order as appears in orig. data)
@@ -233,8 +257,8 @@ between.default.collapse <- function(x, effect, ...) {
   return(res)
 }
 
-Between.pseries.collapse <- function(x, effect = c("individual", "time", "group"), ...) {
-# print("Between.pseries.collapse")
+Between_pseries_collapse <- function(x, effect = c("individual", "time", "group"), ...) {
+# print("Between_pseries_collapse")
 # browser()
   
   # translate arguments
@@ -258,9 +282,10 @@ Between.pseries.collapse <- function(x, effect = c("individual", "time", "group"
   return(res)
 }
 
-between.pseries.collapse <- function(x, effect = c("individual", "time", "group"), ...) {
-# print("between.pseries.collapse")
+between_pseries_collapse <- function(x, effect = c("individual", "time", "group"), ...) {
+# print("between_pseries_collapse")
 # browser()
+  
   effect <- match.arg(effect)
   # check for presence of na.rm in dots, if not present set to FALSE
   na.rm <- if(missing(...) || is.null(na.rm <- list(...)$na.rm)) FALSE else na.rm
@@ -277,7 +302,7 @@ between.pseries.collapse <- function(x, effect = c("individual", "time", "group"
   # (otherwise result could contain non-intended NA)]
   res <- collapse::fbetween(x, effect = eff.no, w = NULL, na.rm = na.rm, fill = TRUE)
   res <- remove_pseries_features(res)
-  keep <- !duplicated(i)
+  keep <- !collapse::fduplicated(i, all = FALSE)
   res <- res[keep]
   names(res) <- as.character(i[keep])
   # bring into factor level order (not order as appears in orig. data)
@@ -288,9 +313,10 @@ between.pseries.collapse <- function(x, effect = c("individual", "time", "group"
 
 
 
-Between.matrix.collapse <- function(x, effect, ...) {
-# print("Between.matrix.collapse")
+Between_matrix_collapse <- function(x, effect, ...) {
+# print("Between_matrix_collapse")
 # browser()
+  
   # if no index attribute, argument 'effect' is assumed to be a factor
   eff.fac <- if(is.null(xindex <- attr(x, "index"))) {
     effect
@@ -318,9 +344,10 @@ Between.matrix.collapse <- function(x, effect, ...) {
   return(res)
 }
 
-between.matrix.collapse <- function(x, effect, ...) {
-# print("between.matrix.collapse")
+between_matrix_collapse <- function(x, effect, ...) {
+# print("between_matrix_collapse")
 # browser()
+  
   # if no index attribute, argument 'effect' is assumed to be a factor
   eff.fac <- if(is.null(xindex <- attr(x, "index"))) {
     effect
@@ -343,7 +370,7 @@ between.matrix.collapse <- function(x, effect, ...) {
   res <- collapse::fbetween(x, g = eff.fac, w = NULL, na.rm = na.rm, fill = TRUE)
   rownames(res) <- as.character(eff.fac)
   # compress data to number of unique individuals (or time periods)
-  res <- res[!duplicated(eff.fac), , drop = FALSE]
+  res <- res[!collapse::fduplicated(eff.fac, all = FALSE), , drop = FALSE]
   # bring into factor level order (not order as appears in orig. data)
   lvl <- levels(collapse::fdroplevels(eff.fac))
   res <- res[lvl, , drop = FALSE]
@@ -354,8 +381,8 @@ between.matrix.collapse <- function(x, effect, ...) {
 #### Within ####
 # Within - default
 
-Within.default.collapse <- function(x, effect, ...) {
-# print("Within.default.collapse")
+Within_default_collapse <- function(x, effect, ...) {
+# print("Within_default_collapse")
 # browser()
   
   # argument 'effect' is assumed to be a factor
@@ -369,9 +396,10 @@ Within.default.collapse <- function(x, effect, ...) {
 }
 
 
-Within.pseries.collapse <- function(x, effect = c("individual", "time", "group", "twoways"), ...) {
-# print("Within.pseries.collapse")
+Within_pseries_collapse <- function(x, effect = c("individual", "time", "group", "twoways"), ...) {
+# print("Within_pseries_collapse")
 # browser()
+  
   effect <- match.arg(effect)
   # check for presence of na.rm in dots, if not present set to FALSE
   na.rm <- if(missing(...) || is.null(na.rm <- list(...)$na.rm)) FALSE else na.rm
@@ -404,8 +432,8 @@ Within.pseries.collapse <- function(x, effect = c("individual", "time", "group",
   return(res)
 }
 
-Within.matrix.collapse <- function(x, effect, ...) {
-# print("Within.matrix.collapse")
+Within_matrix_collapse <- function(x, effect, ...) {
+# print("Within_matrix_collapse")
 # browser()
   
   # check for presence of na.rm in dots, if not present set to FALSE
@@ -461,9 +489,10 @@ Within.matrix.collapse <- function(x, effect, ...) {
 #### the 2-way within transformation which are dramatically faster than
 #### the implementation via separate collapse::fwithin calls (due to the special
 #### algorithms used to partial out the fixed effects)
-Within.pseries.collapse.fixest <- function(x, effect = c("individual", "time", "group", "twoways"), ...) {
-# print("Within.pseries.collapse.fixest")
+Within_pseries_collapse_fixest <- function(x, effect = c("individual", "time", "group", "twoways"), ...) {
+# print("Within_pseries_collapse_fixest")
 # browser()
+  
   effect <- match.arg(effect)
   # check for presence of na.rm in dots, if not present set to FALSE
   na.rm <- if(missing(...) || is.null(na.rm <- list(...)$na.rm)) FALSE else na.rm
@@ -487,8 +516,8 @@ Within.pseries.collapse.fixest <- function(x, effect = c("individual", "time", "
   return(res)
 }
 
-Within.matrix.collapse.fixest <- function(x, effect, ...) {
-# print("Within.matrix.collapse.fixest")
+Within_matrix_collapse_fixest <- function(x, effect, ...) {
+# print("Within_matrix_collapse_fixest")
 # browser()
   
   # check for presence of na.rm in dots, if not present set to FALSE
@@ -525,8 +554,8 @@ Within.matrix.collapse.fixest <- function(x, effect, ...) {
   return(result)
 }
 
-Within.pseries.collapse.lfe <- function(x, effect = c("individual", "time", "group", "twoways"), ...) {
-# print("Within.pseries.collapse.lfe")
+Within_pseriesc_collapse_lfe <- function(x, effect = c("individual", "time", "group", "twoways"), ...) {
+# print("Within_pseriesc_collapse_lfe")
 # browser()
 
   effect <- match.arg(effect)
@@ -553,8 +582,8 @@ Within.pseries.collapse.lfe <- function(x, effect = c("individual", "time", "gro
   return(res)
 }
 
-Within.matrix.collapse.lfe <- function(x, effect,  ...) {
-# print("Within.matrix.collapse.lfe")
+Within_matrix_collapse_lfe <- function(x, effect,  ...) {
+# print("Within_matrix_collapse_lfe")
 # browser()
   
   # check for presence of na.rm in dots, if not present set to FALSE
@@ -595,15 +624,68 @@ Within.matrix.collapse.lfe <- function(x, effect,  ...) {
   return(result)
 }
 
-#### wrapper for pseriesfy ####
-# both pseriesfy functions are in file tool_pdata.frame.R 
-pseriesfy <- function(x,  ...) {
-  if(!isTRUE(getOption("plm.fast"))) {
-    pseriesfy.baseR(x, ...) } else {
-      if(!isTRUE(getOption("plm.fast.pkg.collapse"))) stop(txt.no.collapse, call. = FALSE)
-      pseriesfy.collapse(x, ...) }
+pdiff.collapse <- function(x, effect = c("individual", "time"), has.intercept = FALSE, shift = c("time", "row")){
+  # NB: x is assumed to have an index attribute
+  #     can check with has.index(x)
+  # TODO: pdiff's usage in model.matrix is not very elegant as pdiff does its own
+  #     removal of constant columns and intercept handling which could be handled
+  #     via model.matrix.
+  
+  effect <- match.arg(effect)
+  shift <- match.arg(shift)
+  xindex <- unclass(attr(x, "index"))
+  checkNA.index(xindex) # index may not contain any NA
+
+  if(shift == "row") {
+    eff.no <- switch(effect,
+                     "individual" = 1L,
+                     "time"       = 2L,
+                     stop("unknown value of argument 'effect'"))
+    
+    eff.fac <- xindex[[eff.no]]
+    
+    if(inherits(x, "pseries")) x <- remove_pseries_features(x)
+    res <- collapse::fdiff(x, g = eff.fac)
+    
+  } else {
+    # shift = "time"
+    
+    # make a pdata.frame the dirty way (esp. to keep names like "(Intercept)")
+    # .. works as x is already ensured to be panel-stacked
+    # and apply collapse::fdiff on it
+    if(is.matrix(x)) {
+      x.pdf <- as.data.frame(x)
+      class(x.pdf) <- c("pdata.frame", class(x.pdf))
+      attr(x.pdf, "index") <- attr(x, "index")
+      
+      res <- collapse::fdiff(x.pdf)
+      res <- as.matrix(res)  
+    } else {
+      # pseries case
+      res <- collapse::fdiff(x)
+    }
+  }
+
+  ## last data preparation before return
+  res <- na.omit(res)
+  if(is.matrix(x)) {
+    # original pdiff (coded in base R) removes constant columns in matrix, 
+    # so do likewise collapse-powered version
+    cst.col <- apply(res, 2, is.constant)
+    res <- res[ , !cst.col, drop = FALSE]
+    
+    # if intercept is requested, set intercept column to 1 as it was 
+    # diff'ed out by collapse::fdiff and anyways removed by the removal of
+    # constant columns just above
+    if(has.intercept){
+      res <- cbind(1, res)
+      colnames(res)[1L] <- "(Intercept)"
+    }
+  }
+  res
 }
 
+
 .onAttach <- function(libname, pkgname) {
   options("plm.fast" = TRUE) # since 2.6: needs pkg collapse as hard dependency
   
@@ -661,7 +743,7 @@ pseriesfy <- function(x,  ...) {
 #' effect case is enabled automatically (`fixest` wins over `lfe`),
 #' given one of the packages is detected and `options("plm.fast" = TRUE)` 
 #' (default) is set. If so, the packages' fast algorithms to partial out fixed 
-#' effects are #' used (`fixest::demean` (via `collapse::fhdwithin`), 
+#' effects are used (`fixest::demean` (via `collapse::fhdwithin`), 
 #' `lfe::demeanlist`). Both packages are 'Suggests' dependencies.
 #' 
 #' Users might experience neglectable numerical differences between enabled and
@@ -676,7 +758,9 @@ pseriesfy <- function(x,  ...) {
 #'   \item Between,
 #'   \item Sum,
 #'   \item Within,
-#'   \item pseriesfy.
+#'   \item lag, lead, and diff,
+#'   \item pseriesfy,
+#'   \item pdiff (internal function).
 #' }
 #' 
 #' @name plm.fast
@@ -712,9 +796,9 @@ pseriesfy <- function(x,  ...) {
 #' onewayFE <- microbenchmark(
 #'  {options("plm.fast" = FALSE); plm(form, data = data, model = "within")},
 #'  {options("plm.fast" = TRUE);  plm(form, data = data, model = "within")},
-#'   times = times, unit = "relative")
+#'   times = times)
 #'
-#' summary(onewayFE)
+#' summary(onewayFE, unit = "relative")
 #'
 #' ## two-ways FE benchmark requires pkg fixest and lfe
 #' ## (End-users shall only set option plm.fast. Option plm.fast.pkg.FE.tw shall
@@ -733,24 +817,24 @@ pseriesfy <- function(x,  ...) {
 #'     plm(form, data = data, model = "within", effect = "twoways")},
 #'  {options("plm.fast" = TRUE, "plm.fast.pkg.FE.tw" = "lfe");
 #'     plm(form, data = data, model = "within", effect = "twoways")},
-#'   times = times, unit = "relative")
+#'   times = times)
 #'
-#' summary(twowayFE)
+#' summary(twowayFE, unit = "relative")
 #' }
 #' 
 #' onewayRE <- microbenchmark(
 #'  {options("plm.fast" = FALSE); plm(form, data = data, model = "random")},
 #'  {options("plm.fast" = TRUE);  plm(form, data = data, model = "random")},
-#'   times = times, unit = "relative")
+#'   times = times)
 #'
-#' summary(onewayRE)
+#' summary(onewayRE, unit = "relative")
 #' 
 #' twowayRE <-  microbenchmark(
 #'  {options("plm.fast" = FALSE); plm(form, data = data, model = "random", effect = "twoways")},
 #'  {options("plm.fast" = TRUE);  plm(form, data = data, model = "random", effect = "twoways")},
-#'   times = times, unit = "relative")
+#'   times = times)
 #' 
-#' summary(twowayRE)
+#' summary(twowayRE, unit = "relative")
 #' }
 NULL
 
